@@ -991,7 +991,10 @@ class Test_AsyncJob(unittest.TestCase):
         custom_predicate = mock.Mock()
         custom_predicate.return_value = True
         custom_retry = google.api_core.retry.Retry(
-            predicate=custom_predicate, initial=0.001, maximum=0.001, deadline=0.1,
+            predicate=custom_predicate,
+            initial=0.001,
+            maximum=0.001,
+            deadline=0.1,
         )
         self.assertIs(job.result(retry=custom_retry), job)
 
