@@ -19,18 +19,7 @@ import unittest
 
 import mock
 
-try:
-    from google.cloud import bigquery_storage
-except ImportError:  # pragma: NO COVER
-    bigquery_storage = None
 
-try:
-    import pyarrow
-except ImportError:  # pragma: NO COVER
-    pyarrow = None
-
-
-@unittest.skipIf(bigquery_storage is None, "Requires `google-cloud-bigquery-storage`")
 class TestBQStorageVersions(unittest.TestCase):
     def tearDown(self):
         from google.cloud.bigquery import _helpers
@@ -43,37 +32,6 @@ class TestBQStorageVersions(unittest.TestCase):
 
         return _helpers.BQStorageVersions()
 
-    def _call_fut(self):
-        from google.cloud.bigquery import _helpers
-
-        _helpers.BQ_STORAGE_VERSIONS._installed_version = None
-        return _helpers.BQ_STORAGE_VERSIONS.verify_version()
-
-    def test_raises_no_error_w_recent_bqstorage(self):
-        from google.cloud.bigquery.exceptions import LegacyBigQueryStorageError
-
-        with mock.patch("google.cloud.bigquery_storage.__version__", new="2.0.0"):
-            try:
-                self._call_fut()
-            except LegacyBigQueryStorageError:  # pragma: NO COVER
-                self.fail("Legacy error raised with a non-legacy dependency version.")
-
-    def test_raises_error_w_legacy_bqstorage(self):
-        from google.cloud.bigquery.exceptions import LegacyBigQueryStorageError
-
-        with mock.patch("google.cloud.bigquery_storage.__version__", new="1.9.9"):
-            with self.assertRaises(LegacyBigQueryStorageError):
-                self._call_fut()
-
-    def test_raises_error_w_unknown_bqstorage_version(self):
-        from google.cloud.bigquery.exceptions import LegacyBigQueryStorageError
-
-        with mock.patch("google.cloud.bigquery_storage", autospec=True) as fake_module:
-            del fake_module.__version__
-            error_pattern = r"version found: 0.0.0"
-            with self.assertRaisesRegex(LegacyBigQueryStorageError, error_pattern):
-                self._call_fut()
-
     def test_installed_version_returns_cached(self):
         versions = self._object_under_test()
         versions._installed_version = object()
@@ -100,7 +58,6 @@ class TestBQStorageVersions(unittest.TestCase):
             assert not versions.is_read_session_optional
 
 
-@unittest.skipIf(pyarrow is None, "Requires `pyarrow`")
 class TestPyarrowVersions(unittest.TestCase):
     def tearDown(self):
         from google.cloud.bigquery import _helpers
@@ -113,34 +70,6 @@ class TestPyarrowVersions(unittest.TestCase):
 
         return _helpers.PyarrowVersions()
 
-    def _call_try_import(self, **kwargs):
-        from google.cloud.bigquery import _helpers
-
-        _helpers.PYARROW_VERSIONS._installed_version = None
-        return _helpers.PYARROW_VERSIONS.try_import(**kwargs)
-
-    def test_try_import_raises_no_error_w_recent_pyarrow(self):
-        from google.cloud.bigquery.exceptions import LegacyPyarrowError
-
-        with mock.patch("pyarrow.__version__", new="5.0.0"):
-            try:
-                pyarrow = self._call_try_import(raise_if_error=True)
-                self.assertIsNotNone(pyarrow)
-            except LegacyPyarrowError:  # pragma: NO COVER
-                self.fail("Legacy error raised with a non-legacy dependency version.")
-
-    def test_try_import_returns_none_w_legacy_pyarrow(self):
-        with mock.patch("pyarrow.__version__", new="2.0.0"):
-            pyarrow = self._call_try_import()
-            self.assertIsNone(pyarrow)
-
-    def test_try_import_raises_error_w_legacy_pyarrow(self):
-        from google.cloud.bigquery.exceptions import LegacyPyarrowError
-
-        with mock.patch("pyarrow.__version__", new="2.0.0"):
-            with self.assertRaises(LegacyPyarrowError):
-                self._call_try_import(raise_if_error=True)
-
     def test_installed_version_returns_cached(self):
         versions = self._object_under_test()
         versions._installed_version = object()
